================
Using Extensions
================

Extensions build on the core behavior or recipe to let you perform

.. toctree::
   :caption: Built-in extensions
   :maxdepth: 3

   automaticfilters
   summarizeover
   comparerecipe
   blendrecipe
   anonymize